==> zio-aws-networkmanager_3-5.17.103.1-sources.jar: zio/aws/networkmanager/model/AssociateConnectPeerRequest.scala <==
package zio.aws.networkmanager.model
import zio.ZIO
import zio.aws.networkmanager.model.primitives.{
  LinkId,
  DeviceId,
  ConnectPeerId,
  GlobalNetworkId
}
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class AssociateConnectPeerRequest(
    globalNetworkId: GlobalNetworkId,
    connectPeerId: ConnectPeerId,
    deviceId: DeviceId,
    linkId: Option[LinkId] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.networkmanager.model.AssociateConnectPeerRequest = {
    import AssociateConnectPeerRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.networkmanager.model.AssociateConnectPeerRequest
      .builder()
      .globalNetworkId(
        GlobalNetworkId.unwrap(globalNetworkId): java.lang.String
      )
      .connectPeerId(ConnectPeerId.unwrap(connectPeerId): java.lang.String)
      .deviceId(DeviceId.unwrap(deviceId): java.lang.String)
      .optionallyWith(
        linkId.map(value => LinkId.unwrap(value): java.lang.String)
      )(_.linkId)
      .build()
  }
  def asReadOnly
      : zio.aws.networkmanager.model.AssociateConnectPeerRequest.ReadOnly =
    zio.aws.networkmanager.model.AssociateConnectPeerRequest
      .wrap(buildAwsValue())
}
object AssociateConnectPeerRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.networkmanager.model.AssociateConnectPeerRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.networkmanager.model.AssociateConnectPeerRequest =
      zio.aws.networkmanager.model.AssociateConnectPeerRequest(
        globalNetworkId,
        connectPeerId,
        deviceId,
        linkId.map(value => value)
      )
    def globalNetworkId: GlobalNetworkId
    def connectPeerId: ConnectPeerId
    def deviceId: DeviceId
    def linkId: Option[LinkId]
    def getGlobalNetworkId: ZIO[Any, Nothing, GlobalNetworkId] =
      ZIO.succeed(globalNetworkId)
    def getConnectPeerId: ZIO[Any, Nothing, ConnectPeerId] =
      ZIO.succeed(connectPeerId)
    def getDeviceId: ZIO[Any, Nothing, DeviceId] = ZIO.succeed(deviceId)
    def getLinkId: ZIO[Any, AwsError, LinkId] =
      AwsError.unwrapOptionField("linkId", linkId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.networkmanager.model.AssociateConnectPeerRequest
  ) extends zio.aws.networkmanager.model.AssociateConnectPeerRequest.ReadOnly {
    override val globalNetworkId: GlobalNetworkId =
      zio.aws.networkmanager.model.primitives
        .GlobalNetworkId(impl.globalNetworkId())
    override val connectPeerId: ConnectPeerId =
      zio.aws.networkmanager.model.primitives
        .ConnectPeerId(impl.connectPeerId())
    override val deviceId: DeviceId =
      zio.aws.networkmanager.model.primitives.DeviceId(impl.deviceId())
    override val linkId: Option[LinkId] = scala
      .Option(impl.linkId())
      .map(value => zio.aws.networkmanager.model.primitives.LinkId(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.networkmanager.model.AssociateConnectPeerRequest
  ): zio.aws.networkmanager.model.AssociateConnectPeerRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-networkmanager_3-7.21.15.3-sources.jar: zio/aws/networkmanager/model/AssociateConnectPeerRequest.scala <==
package zio.aws.networkmanager.model
import zio.ZIO
import zio.aws.networkmanager.model.primitives.{
  LinkId,
  DeviceId,
  ConnectPeerId,
  GlobalNetworkId
}
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class AssociateConnectPeerRequest(
    globalNetworkId: GlobalNetworkId,
    connectPeerId: ConnectPeerId,
    deviceId: DeviceId,
    linkId: Optional[LinkId] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.networkmanager.model.AssociateConnectPeerRequest = {
    import AssociateConnectPeerRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.networkmanager.model.AssociateConnectPeerRequest
      .builder()
      .globalNetworkId(
        GlobalNetworkId.unwrap(globalNetworkId): java.lang.String
      )
      .connectPeerId(ConnectPeerId.unwrap(connectPeerId): java.lang.String)
      .deviceId(DeviceId.unwrap(deviceId): java.lang.String)
      .optionallyWith(
        linkId.map(value => LinkId.unwrap(value): java.lang.String)
      )(_.linkId)
      .build()
  }
  def asReadOnly
      : zio.aws.networkmanager.model.AssociateConnectPeerRequest.ReadOnly =
    zio.aws.networkmanager.model.AssociateConnectPeerRequest
      .wrap(buildAwsValue())
}
object AssociateConnectPeerRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.networkmanager.model.AssociateConnectPeerRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.networkmanager.model.AssociateConnectPeerRequest =
      zio.aws.networkmanager.model.AssociateConnectPeerRequest(
        globalNetworkId,
        connectPeerId,
        deviceId,
        linkId.map(value => value)
      )
    def globalNetworkId: GlobalNetworkId
    def connectPeerId: ConnectPeerId
    def deviceId: DeviceId
    def linkId: Optional[LinkId]
    def getGlobalNetworkId: ZIO[Any, Nothing, GlobalNetworkId] =
      ZIO.succeed(globalNetworkId)
    def getConnectPeerId: ZIO[Any, Nothing, ConnectPeerId] =
      ZIO.succeed(connectPeerId)
    def getDeviceId: ZIO[Any, Nothing, DeviceId] = ZIO.succeed(deviceId)
    def getLinkId: ZIO[Any, AwsError, LinkId] =
      AwsError.unwrapOptionField("linkId", linkId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.networkmanager.model.AssociateConnectPeerRequest
  ) extends zio.aws.networkmanager.model.AssociateConnectPeerRequest.ReadOnly {
    override val globalNetworkId: GlobalNetworkId =
      zio.aws.networkmanager.model.primitives
        .GlobalNetworkId(impl.globalNetworkId())
    override val connectPeerId: ConnectPeerId =
      zio.aws.networkmanager.model.primitives
        .ConnectPeerId(impl.connectPeerId())
    override val deviceId: DeviceId =
      zio.aws.networkmanager.model.primitives.DeviceId(impl.deviceId())
    override val linkId: Optional[LinkId] = zio.aws.core.internal
      .optionalFromNullable(impl.linkId())
      .map(value => zio.aws.networkmanager.model.primitives.LinkId(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.networkmanager.model.AssociateConnectPeerRequest
  ): zio.aws.networkmanager.model.AssociateConnectPeerRequest.ReadOnly =
    new Wrapper(impl)
}
